summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneylineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneylineedit.h')
-rw-r--r--kmymoney2/widgets/kmymoneylineedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmymoney2/widgets/kmymoneylineedit.h b/kmymoney2/widgets/kmymoneylineedit.h
index e97205d..30d079e 100644
--- a/kmymoney2/widgets/kmymoneylineedit.h
+++ b/kmymoney2/widgets/kmymoneylineedit.h
@@ -52,10 +52,10 @@ public:
* @param name pointer to name of object
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
* value and does not follow the keyboard tqlayout (default: @p false)
* @param tqalignment Controls the tqalignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
* See TQt::AlignmentFlags for other possible values.
*/
- kMyMoneyLineEdit(TQWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int tqalignment = (AlignLeft | AlignVCenter));
+ kMyMoneyLineEdit(TQWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int alignment = (AlignLeft | AlignVCenter));
~kMyMoneyLineEdit();
/**
@@ -52,10 +52,10 @@ public:
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
* value and does not follow the keyboard tqlayout (default: @p false)
- * @param tqalignment Controls the tqalignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
+ * @param alignment Controls the alignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
* See TQt::AlignmentFlags for other possible values.
*/